library(hisse)
library(parallel)
	
	nwo = read.tree("Sula_beast.303.bdu.nwk")
	host = read.table("Sula_lifestyle.303.txt")
	states = host[,2]
	names(states) = host[,1]

#### BiSSE-like HiSSE models ####

##   Set up the transition matrices

     BiSSE.trans.rate<-TransMatMaker()
 	 BiSSE.trans.rate.red <- BiSSE.trans.rate
	 BiSSE.trans.rate.red[!is.na(BiSSE.trans.rate.red)] = 1


###  1. Full BiSSE-like model with all free parameters (lambda0, lambda1, mu0, mu1, q01, q10)

##   Fit the BiSSE-like HiSSE model

	 BiSSE_free <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=FALSE, turnover.anc=c(1,2,0,0), eps.anc=c(1,2,0,0), trans.rate=BiSSE.trans.rate)

##   Reconstruct states under the BiSSE-like model

	 BiSSE_free_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=BiSSE_free$solution, hidden.states=F, aic=BiSSE_free$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(BiSSE_free$loglik, BiSSE_free$AIC, max(BiSSE_free $index.par)-1, BiSSE_free$solution)), file="empirical.results.BiSSE.neb.txt", quote=FALSE, sep="\t", row.names=T, col.names=F, append=TRUE)


###  3. BiSSE-like model with equal mu (lambda0, lambda1, mu0 ~ mu1, q01, q10)

##   Fit the BiSSE-like HiSSE model

	 BiSSE_eqm <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=FALSE, turnover.anc=c(1,2,0,0), eps.anc=c(1,1,0,0), trans.rate=BiSSE.trans.rate)

##   Reconstruct states under the BiSSE-like model

	 BiSSE_eqm_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=BiSSE_eqm$solution, hidden.states=F, aic=BiSSE_eqm$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(BiSSE_eqm$loglik, BiSSE_eqm$AIC, max(BiSSE_eqm $index.par)-1, BiSSE_eqm$solution)), file="empirical.results.BiSSE.neb.txt", quote=FALSE, sep="\t", row.names=T, col.names=F, append=TRUE)


###  4. BiSSE-like model with equal transition rates (lambda0, lambda1, mu0, mu1, q01 ~ q10)

##   Fit the BiSSE-like HiSSE model

	 BiSSE_eqq <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=FALSE, turnover.anc=c(1,2,0,0), eps.anc=c(1,2,0,0), trans.rate=BiSSE.trans.rate.red)

##   Reconstruct states under the BiSSE-like model

	 BiSSE_eqq_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=BiSSE_eqq$solution, hidden.states=F, aic=BiSSE_eqq$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(BiSSE_eqq$loglik, BiSSE_eqq$AIC, max(BiSSE_eqq $index.par)-1, BiSSE_eqq$solution)), file="empirical.results.BiSSE.neb.txt", quote=FALSE, sep="\t", row.names=T, col.names=F, append=TRUE)


###  6. BiSSE-like model with equal mu and transition rates (lambda0, lambda1, mu0 ~ mu1, q01 ~ q10)

##   Fit the BiSSE-like HiSSE model

	 BiSSE_eqmq <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=FALSE, turnover.anc=c(1,2,0,0), eps.anc=c(1,1,0,0), trans.rate=BiSSE.trans.rate.red)

##   Reconstruct states under the BiSSE-like model

	 BiSSE_eqmq_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=BiSSE_eqmq$solution, hidden.states=F, aic=BiSSE_eqmq$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(BiSSE_eqmq$loglik, BiSSE_eqmq$AIC, max(BiSSE_eqmq $index.par)-1, BiSSE_eqmq$solution)), file="empirical.results.BiSSE.neb.txt", quote=FALSE, sep="\t", row.names=T, col.names=F, append=TRUE)
