library(hisse)
library(parallel)
	
	nwo = read.tree("Sula_beast.303.bdu.nwk")
	host = read.table("Sula_lifestyle.303.txt")
	states = host[,2]
	names(states) = host[,1]

#### HiSSE models ####

##   Set up the transition matrices

     HiSSE.trans.rates <- TransMatMaker(hidden.states=TRUE)
     HiSSE.trans.rates.nodual <- ParDrop(HiSSE.trans.rates, c(3,5,8,10))
     
     HiSSE.trans.rates.threerates <- HiSSE.trans.rates.nodual
     to.change <- cbind(c(1,3), c(2,4))
     HiSSE.trans.rates.threerates[to.change] <- 1
     to.change <- cbind(c(2,4), c(1,3))
     HiSSE.trans.rates.threerates[to.change] <- 2
     to.change <- cbind(c(1,3,2,4), c(3,1,4,2))
     HiSSE.trans.rates.threerates[to.change] <- 3
     
	 HiSSE.trans.rates.eqB <- TransMatMaker(hidden.states=TRUE)
	 HiSSE.trans.rates.eqB <- ParDrop(HiSSE.trans.rates.eqB, c(3,5,8,9,10,12))

	 HiSSE.trans.rates.equal <- HiSSE.trans.rates.nodual

	 HiSSE.trans.rates.equal.eqB <- HiSSE.trans.rates.eqB
	 HiSSE.trans.rates.equal[!is.na(HiSSE.trans.rates.equal) & !HiSSE.trans.rates.equal == 0] = 1
	 HiSSE.trans.rates.equal.eqB[!is.na(HiSSE.trans.rates.equal.eqB) & !HiSSE.trans.rates.equal.eqB == 0] = 1




     
#### HiSSE models
     
###  1. 56	 HiSSE	 q's equal - 9 parameters

     HiSSE_56 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,3,4), eps.anc=c(1,2,3,4), trans.rate=HiSSE.trans.rates.equal)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_56_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_56$solution, hidden.states=T, aic=HiSSE_56$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_56$loglik, HiSSE_56$AIC, max(HiSSE_56 $index.par)-1, HiSSE_56$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="1", col.names=F, append=TRUE)



###  2. 62	 HiSSE	 eps's equal, q's equal - 6 parameters
    
     HiSSE_62 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,3,4), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.equal)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_62_States<-MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_62$solution, hidden.states=T, aic=HiSSE_62$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_62$loglik, HiSSE_62$AIC, max(HiSSE_62 $index.par)-1, HiSSE_62$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="2", col.names=F, append=TRUE)



###  3. 68	 HiSSE	 tau0A=tau1A=tau0B, eps0A=eps1A=eps0B, q's equal - 5 parameters

     HiSSE_68 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,1,2), eps.anc=c(1,1,1,2), trans.rate=HiSSE.trans.rates.equal)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_68_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_68$solution, hidden.states=T, aic=HiSSE_68$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_68$loglik, HiSSE_68$AIC, max(HiSSE_68 $index.par)-1, HiSSE_68$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="3", col.names=F, append=TRUE)



###  4. 74	 HiSSE	 tau0A=tau1A=tau0B, eps's equal, q's equal - 4 parameters

     HiSSE_74 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,1,2), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.equal)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_74_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_74$solution, hidden.states=T, aic=HiSSE_74$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_74$loglik, HiSSE_74$AIC, max(HiSSE_74 $index.par)-1, HiSSE_74$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="4", col.names=F, append=TRUE)



###  5. 80	 HiSSE	 q0B1B=0, q1B0B=0, all other q's equal - 9 parameters

     HiSSE_80 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,3,4), eps.anc=c(1,2,3,4), trans.rate=HiSSE.trans.rates.equal.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_80_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_80$solution, hidden.states=T, aic=HiSSE_80$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_80$loglik, HiSSE_80$AIC, max(HiSSE_80 $index.par)-1, HiSSE_80$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="5", col.names=F, append=TRUE)



###  6. 86	 HiSSE	 eps's equal, q0B1B=0, q1B0B=0, all other q's equal - 6 parameters

     HiSSE_86 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,3,4), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.equal.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_86_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_86$solution, hidden.states=T, aic=HiSSE_86$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_86$loglik, HiSSE_86$AIC, max(HiSSE_86 $index.par)-1, HiSSE_86$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="6", col.names=F, append=TRUE)



###  7. 92	 HiSSE	 tau0A=tau1A=tau0B, eps0A=eps1A=eps0B, q0B1B=0, q1B0B=0, all other q's equal - 5 parameters

     HiSSE_92 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,1,2), eps.anc=c(1,1,1,2), trans.rate=HiSSE.trans.rates.equal.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_92_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_92$solution, hidden.states=T, aic=HiSSE_92$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_92$loglik, HiSSE_92$AIC, max(HiSSE_92 $index.par)-1, HiSSE_92$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="7", col.names=F, append=TRUE)



###  8. 98	 HiSSE	 tau0A=tau1A=tau0B, eps'sequal, q0B1B=0, q1B0B=0, all other q's equal - 4 parameters

     HiSSE_98 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,1,2), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.equal.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_98_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_98$solution, hidden.states=T, aic=HiSSE_98$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_98$loglik, HiSSE_98$AIC, max(HiSSE_98 $index.par)-1, HiSSE_98$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="8", col.names=F, append=TRUE)



###  9. 104	 HiSSE	 tau0A=tau1A, eps0A=eps1A, q's equal - 7 parameters

     HiSSE_104 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,2,3), eps.anc=c(1,1,2,3), trans.rate=HiSSE.trans.rates.equal)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_104_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_104$solution, hidden.states=T, aic=HiSSE_104$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_104$loglik, HiSSE_104$AIC, max(HiSSE_104 $index.par)-1, HiSSE_104$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="9", col.names=F, append=TRUE)



###  10. 110	 HiSSE	 tau0A=tau1A, eps's equal, q's equal - 5 parameters

     HiSSE_110 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,2,3), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.equal)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_110_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_110$solution, hidden.states=T, aic=HiSSE_110$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_110$loglik, HiSSE_110$AIC, max(HiSSE_110 $index.par)-1, HiSSE_110$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="10", col.names=F, append=TRUE)



###  11. 116	 HiSSE	 tau0A=tau1A, eps0A=eps1A, q0B1B=0, q1B0B=0, all other q's equal - 7 parameters

     HiSSE_116 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,2,3), eps.anc=c(1,1,2,3), trans.rate=HiSSE.trans.rates.equal.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_116_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_116$solution, hidden.states=T, aic=HiSSE_116$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_116$loglik, HiSSE_116$AIC, max(HiSSE_116 $index.par)-1, HiSSE_116$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="11", col.names=F, append=TRUE)



###  12. 122	 HiSSE	 tau0A=tau1A, eps's equal, q0B1B=0, q1B0B=0, all other q's equal - 5 parameters

     HiSSE_122 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,2,3), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.equal.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_122_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_122$solution, hidden.states=T, aic=HiSSE_122$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_122$loglik, HiSSE_122$AIC, max(HiSSE_122 $index.par)-1, HiSSE_122$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="12", col.names=F, append=TRUE)



###  13. 128	 HiSSE	 tau0A=tau0B, eps0A=eps0B, q's equal - 7 parameters

     HiSSE_128 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,1,3), eps.anc=c(1,2,1,3), trans.rate=HiSSE.trans.rates.equal)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_128_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_128$solution, hidden.states=T, aic=HiSSE_128$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_128$loglik, HiSSE_128$AIC, max(HiSSE_128 $index.par)-1, HiSSE_128$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="13", col.names=F, append=TRUE)



###  14. 134	 HiSSE	 tau0A=tau0B, eps's equal, q's equal - 5 parameters

     HiSSE_134 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,1,3), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.equal)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_134_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_134$solution, hidden.states=T, aic=HiSSE_134$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_134$loglik, HiSSE_134$AIC, max(HiSSE_134 $index.par)-1, HiSSE_134$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="14", col.names=F, append=TRUE)



###  15. 140	 HiSSE	 tau0A=tau0B, eps0A=eps0B, q0B1B=0, q1B0B=0, all other q's equal - 7 parameters

     HiSSE_140 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,1,3), eps.anc=c(1,2,1,3), trans.rate=HiSSE.trans.rates.equal.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_140_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_140$solution, hidden.states=T, aic=HiSSE_140$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_140$loglik, HiSSE_140$AIC, max(HiSSE_140 $index.par)-1, HiSSE_140$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="15", col.names=F, append=TRUE)



###  16. 146	 HiSSE	 tau0A=tau0B, eps's equal, q0B1B=0, q1B0B=0, all other q's equal - 5 parameters

     HiSSE_146 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,1,3), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.equal.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_146_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_146$solution, hidden.states=T, aic=HiSSE_146$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_146$loglik, HiSSE_146$AIC, max(HiSSE_146 $index.par)-1, HiSSE_146$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="16", col.names=F, append=TRUE)
