library(hisse)
library(parallel)
	
	nwo = read.tree("Sula_beast.303.bdu.nwk")
	host = read.table("Sula_lifestyle.303.txt")
	states = host[,2]
	names(states) = host[,1]

#### HiSSE models ####

##   Set up the transition matrices

     HiSSE.trans.rates <- TransMatMaker(hidden.states=TRUE)
     HiSSE.trans.rates.nodual <- ParDrop(HiSSE.trans.rates, c(3,5,8,10))
     
     HiSSE.trans.rates.threerates <- HiSSE.trans.rates.nodual
     to.change <- cbind(c(1,3), c(2,4))
     HiSSE.trans.rates.threerates[to.change] <- 1
     to.change <- cbind(c(2,4), c(1,3))
     HiSSE.trans.rates.threerates[to.change] <- 2
     to.change <- cbind(c(1,3,2,4), c(3,1,4,2))
     HiSSE.trans.rates.threerates[to.change] <- 3
     
	 HiSSE.trans.rates.eqB <- TransMatMaker(hidden.states=TRUE)
	 HiSSE.trans.rates.eqB <- ParDrop(HiSSE.trans.rates.eqB, c(3,5,8,9,10,12))

	 HiSSE.trans.rates.equal <- HiSSE.trans.rates.nodual

	 HiSSE.trans.rates.equal.eqB <- HiSSE.trans.rates.eqB
	 HiSSE.trans.rates.equal[!is.na(HiSSE.trans.rates.equal) & !HiSSE.trans.rates.equal == 0] = 1
	 HiSSE.trans.rates.equal.eqB[!is.na(HiSSE.trans.rates.equal.eqB) & !HiSSE.trans.rates.equal.eqB == 0] = 1




     
#### HiSSE models

###  17. 176	 HiSSE	 q's diff 

     HiSSE_176 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,3,4), eps.anc=c(1,2,3,4), trans.rate=HiSSE.trans.rates.nodual)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_176_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_176$solution, hidden.states=T, aic=HiSSE_176$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_176$loglik, HiSSE_176$AIC, max(HiSSE_176 $index.par)-1, HiSSE_176$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="17", col.names=F, append=TRUE)


###  18. 182	 HiSSE	 eps's equal, q's diff  

     HiSSE_182 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,3,4), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.nodual)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_182_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_182$solution, hidden.states=T, aic=HiSSE_182$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_182$loglik, HiSSE_182$AIC, max(HiSSE_182 $index.par)-1, HiSSE_182$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="18", col.names=F, append=TRUE)



###  19. 188	 HiSSE	 tau0A=tau1A=tau0B, eps0A=eps1A=eps0B, q's diff  

     HiSSE_188 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,1,2), eps.anc=c(1,1,1,2), trans.rate=HiSSE.trans.rates.nodual)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_188_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_188$solution, hidden.states=T, aic=HiSSE_188$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_188$loglik, HiSSE_188$AIC, max(HiSSE_188 $index.par)-1, HiSSE_188$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="19", col.names=F, append=TRUE)



###  20. 194	 HiSSE	 tau0A=tau1A=tau0B, eps's equal, q's diff 

     HiSSE_194 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,1,2), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.nodual)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_194_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_194$solution, hidden.states=T, aic=HiSSE_194$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_194$loglik, HiSSE_194$AIC, max(HiSSE_194 $index.par)-1, HiSSE_194$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="20", col.names=F, append=TRUE)



###  21. 200	 HiSSE	 q0B1B=0, q1B0B=0, all other q's diff 

     HiSSE_200 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,3,4), eps.anc=c(1,2,3,4), trans.rate=HiSSE.trans.rates.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_200_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_200$solution, hidden.states=T, aic=HiSSE_200$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_200$loglik, HiSSE_200$AIC, max(HiSSE_200 $index.par)-1, HiSSE_200$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="21", col.names=F, append=TRUE)



###  22. 206	 HiSSE	 eps's equal, q0B1B=0, q1B0B=0, all other q's diff 

     HiSSE_206 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,3,4), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_206_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_206$solution, hidden.states=T, aic=HiSSE_206$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_206$loglik, HiSSE_206$AIC, max(HiSSE_206 $index.par)-1, HiSSE_206$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="22", col.names=F, append=TRUE)



###  23. 212	 HiSSE	 tau0A=tau1A=tau0B, eps0A=eps1A=eps0B, q0B1B=0, q1B0B=0, all other q's diff

     HiSSE_212 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,1,2), eps.anc=c(1,1,1,2), trans.rate=HiSSE.trans.rates.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_212_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_212$solution, hidden.states=T, aic=HiSSE_212$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_212$loglik, HiSSE_212$AIC, max(HiSSE_212 $index.par)-1, HiSSE_212$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="23", col.names=F, append=TRUE)



###  24. 218	 HiSSE	 tau0A=tau1A=tau0B, eps's equal, q0B1B=0, q1B0B=0, all other q's diff

     HiSSE_218 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,1,2), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_218_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_218$solution, hidden.states=T, aic=HiSSE_218$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_218$loglik, HiSSE_218$AIC, max(HiSSE_218 $index.par)-1, HiSSE_218$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="24", col.names=F, append=TRUE)



###  25. 224	 HiSSE	 tau0A=tau1A, eps0A=eps1A, q's diff

     HiSSE_224 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,2,3), eps.anc=c(1,1,2,3), trans.rate=HiSSE.trans.rates.nodual)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_224_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_224$solution, hidden.states=T, aic=HiSSE_224$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_224$loglik, HiSSE_224$AIC, max(HiSSE_224 $index.par)-1, HiSSE_224$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="25", col.names=F, append=TRUE)



###  26. 230	 HiSSE	 tau0A=tau1A, eps's equal, q's diff

     HiSSE_230 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,2,3), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.nodual)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_230_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_230$solution, hidden.states=T, aic=HiSSE_230$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_230$loglik, HiSSE_230$AIC, max(HiSSE_230 $index.par)-1, HiSSE_230$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="26", col.names=F, append=TRUE)



###  27. 236	 HiSSE	 tau0A=tau1A, eps0A=eps1A, q0B1B=0, q1B0B=0, all other q's diff

     HiSSE_236 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,2,3), eps.anc=c(1,1,2,3), trans.rate=HiSSE.trans.rates.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_236_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_236$solution, hidden.states=T, aic=HiSSE_236$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_236$loglik, HiSSE_236$AIC, max(HiSSE_236 $index.par)-1, HiSSE_236$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="27", col.names=F, append=TRUE)



###  28. 242	 HiSSE	 tau0A=tau1A, eps's equal, q0B1B=0, q1B0B=0, all other q's diff

     HiSSE_242 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,2,3), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_242_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_242$solution, hidden.states=T, aic=HiSSE_242$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_242$loglik, HiSSE_242$AIC, max(HiSSE_242 $index.par)-1, HiSSE_242$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="28", col.names=F, append=TRUE)



###  29. 248	 HiSSE	 tau0A=tau0B, eps0A=eps0B, q's diff 

     HiSSE_248 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,1,3), eps.anc=c(1,2,1,3), trans.rate=HiSSE.trans.rates.nodual)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_248_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_248$solution, hidden.states=T, aic=HiSSE_248$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_248$loglik, HiSSE_248$AIC, max(HiSSE_248 $index.par)-1, HiSSE_248$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="29", col.names=F, append=TRUE)



###  30. 254	 HiSSE	 tau0A=tau0B, eps's equal, q's diff 

     HiSSE_254 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,1,3), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.nodual)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_254_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_254$solution, hidden.states=T, aic=HiSSE_254$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_254$loglik, HiSSE_254$AIC, max(HiSSE_254 $index.par)-1, HiSSE_254$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="30", col.names=F, append=TRUE)



###  31. 260	 HiSSE	 tau0A=tau0B, eps0A=eps0B, q0B1B=0, q1B0B=0, all other q's diff

     HiSSE_260 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,1,3), eps.anc=c(1,2,1,3), trans.rate=HiSSE.trans.rates.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_260_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_260$solution, hidden.states=T, aic=HiSSE_260$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_260$loglik, HiSSE_260$AIC, max(HiSSE_260 $index.par)-1, HiSSE_260$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="31", col.names=F, append=TRUE)



###  32. 266	 HiSSE	 tau0A=tau0B, eps's equal, q0B1B=0, q1B0B=0, all other q's diff

     HiSSE_266 <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,2,1,3), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.eqB)
    
##   Reconstruct the states under the HiSSE model

##   HiSSE_266_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_266$solution, hidden.states=T, aic=HiSSE_266$AIC, verbose=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_266$loglik, HiSSE_266$AIC, max(HiSSE_266 $index.par)-1, HiSSE_266$solution)), file="empirical.results.HiSSE.neb.txt", quote=FALSE, sep="\t", row.names="32", col.names=F, append=TRUE)
