library(hisse)
library(parallel)
	
	nwo = read.tree("Sula_beast.303.bdu.nwk")
	host = read.table("Sula_lifestyle.303.txt")
	states = host[,2]
	names(states) = host[,1]

#### HiSSE models ####

##   Set up the transition matrices

     HiSSE.trans.rates <- TransMatMaker(hidden.states=TRUE)
     HiSSE.trans.rates.nodual <- ParDrop(HiSSE.trans.rates, c(3,5,8,10))
     
     HiSSE.trans.rates.threerates <- HiSSE.trans.rates.nodual
     to.change <- cbind(c(1,3), c(2,4))
     HiSSE.trans.rates.threerates[to.change] <- 1
     to.change <- cbind(c(2,4), c(1,3))
     HiSSE.trans.rates.threerates[to.change] <- 2
     to.change <- cbind(c(1,3,2,4), c(3,1,4,2))
     HiSSE.trans.rates.threerates[to.change] <- 3
     
	 HiSSE.trans.rates.eqB <- TransMatMaker(hidden.states=TRUE)
	 HiSSE.trans.rates.eqB <- ParDrop(HiSSE.trans.rates.eqB, c(3,5,8,9,10,12))

	 HiSSE.trans.rates.equal <- HiSSE.trans.rates.nodual

	 HiSSE.trans.rates.equal.eqB <- HiSSE.trans.rates.eqB
	 HiSSE.trans.rates.equal[!is.na(HiSSE.trans.rates.equal) & !HiSSE.trans.rates.equal == 0] = 1
	 HiSSE.trans.rates.equal.eqB[!is.na(HiSSE.trans.rates.equal.eqB) & !HiSSE.trans.rates.equal.eqB == 0] = 1




     
#### HiSSE models ####

##   Set up the transition matrices

     HiSSE.trans.rates <- TransMatMaker(hidden.states=TRUE)
     HiSSE.trans.rates.nodual <- ParDrop(HiSSE.trans.rates, c(3,5,8,10))
     HiSSE.trans.rates.equal<-ParEqual(HiSSE.trans.rates.nodual, c(1,2,1,3,1,4,1,5,1,6,1,7,1,8))
    

#### Run the Null-two model ######

     
##  9. HiSSE Null-2 model with equal transition rates
    
     null2_eqrate_full <-hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,2,2), eps.anc=c(1,1,2,2), trans.rate= HiSSE.trans.rates.equal)
    
##   Reconstruct this

##   null2_eqrate_full_States<-MarginRecon(nwo, host, f=c(0.25,0.32), pars=null2_eqrate_full$solution, hidden.states=T, aic=null2_eqrate_full$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(null2_eqrate_full$loglik, null2_eqrate_full$AIC, max(null2_eqrate_full $index.par)-1, null2_eqrate_full$solution)), file="empirical.results.HiSSE.Null2.neb.txt", quote=FALSE, sep="\t", row.names="9", col.names=F, append=TRUE)



##   12. HiSSE Null-2 model with equal transition rates and diversification equal across all states

     null2_deqrate_deq <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,1,1), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.equal)
    
##   Reconstruct this

##   null2_deqrate_deq_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=null2_deqrate_deq$solution, hidden.states=T, aic=null2_deqrate_deq$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(null2_deqrate_deq$loglik, null2_deqrate_deq$AIC, max(null2_deqrate_deq $index.par)-1, null2_deqrate_deq$solution)), file="empirical.results.HiSSE.Null2.neb.txt", quote=FALSE, sep="\t", row.names="12", col.names=F, append=TRUE)



###  1. HiSSE Null-2 model with 8 transition rates
    
     null2_8rate_full <-hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,2,2), eps.anc=c(1,1,2,2), trans.rate=HiSSE.trans.rates.nodual)
    
##   Reconstruct this

##   null2_8rate_full_States<-MarginRecon(nwo, host, f=c(0.25,0.32), pars=null2_8rate_full$solution, hidden.states=T, aic=null2_8rate_full$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(null2_8rate_full$loglik, null2_8rate_full$AIC, max(null2_8rate_full $index.par)-1, null2_8rate_full$solution)), file="empirical.results.HiSSE.Null2.neb.txt", quote=FALSE, sep="\t", row.names="1", col.names=F, append=TRUE)



##   3. HiSSE Null-2 model with 8 transition rates and extinction equal across all states

     null2_8rate_eeq <- hisse(nwo, host, f=c(0.25,0.32), hidden.states=TRUE, turnover.anc=c(1,1,2,2), eps.anc=c(1,1,1,1), trans.rate=HiSSE.trans.rates.nodual)
    
##   Reconstruct this

##   null2_8rate_eeq_states <- MarginRecon(nwo, host, f=c(0.25,0.32), pars=null2_8rate_eeq$solution, hidden.states=T, aic=null2_8rate_eeq$AIC, verbose=T, n.cores=4)

##   Write table

	 write.table(t(c(null2_8rate_eeq$loglik, null2_8rate_eeq$AIC, max(null2_8rate_eeq $index.par)-1, null2_8rate_eeq$solution)), file="empirical.results.HiSSE.Null2.neb.txt", quote=FALSE, sep="\t", row.names="3", col.names=F, append=TRUE)



##### Run the Null-four model ######

##   1. HiSSE Null-4 model with all trans rates equal
    
     HiSSE_null4_eq<-hisse.null4(nwo, host, f=c(0.25,0.32), trans.type="equal")
    
##   Reconstruct this

##   HiSSE_null4_eq_states<-MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_null4_eq$solution, hidden.states=T, aic=HiSSE_null4_eq$AIC, verbose=T, four.state.null=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_null4_eq$loglik, HiSSE_null4_eq$AIC, max(HiSSE_null4_eq $index.par)-1, HiSSE_null4_eq$solution)), file="empirical.results.HiSSE.Null4.neb.txt", quote=FALSE, sep="\t", row.names="1", col.names=F, append=TRUE)



##   2. HiSSE Null-4 model with all trans rates equal
    
     HiSSE_null4_eq1<-hisse.null4(nwo, host, f=c(0.25,0.32), eps.anc=rep(1,8), trans.type="equal")
    
##   Reconstruct this

##   HiSSE_null4_eq1_states<-MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_null4_eq1$solution, hidden.states=T, aic=HiSSE_null4_eq1$AIC, verbose=T, four.state.null=T, n.cores=4)
    
##   Write table

	 write.table(t(c(HiSSE_null4_eq1$loglik, HiSSE_null4_eq1$AIC, max(HiSSE_null4_eq1 $index.par)-1, HiSSE_null4_eq1$solution)), file="empirical.results.HiSSE.Null4.neb.txt", quote=FALSE, sep="\t", row.names="2", col.names=F, append=TRUE)



##   5. HiSSE Null-4 model with 9 transition rates
##   Load in the function to fit the null-four model with 9 transition rates

     source("HiSSE.null4.9rate.R")
     HiSSE_null4_9rates<-hisse.null4.mod.9.rates(nwo, host, f=c(0.25,0.32), trans.type="All.no.dual")
    

##   Reconstruct this
     
##   HiSSE_null4_9rates_states<-MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_null4_9rates$solution, hidden.states=T, aic=HiSSE_null4_9rates$AIC, verbose=T, four.state.null=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_null4_9rates$loglik, HiSSE_null4_9rates$AIC, max(HiSSE_null4_9rates $index.par)-1, HiSSE_null4_9rates$solution)), file="empirical.results.HiSSE.Null4.neb.txt", quote=FALSE, sep="\t", row.names="5", col.names=F, append=TRUE)



##   6. HiSSE Null-4 model with 9 transition rates
##   Load in the function to fit the null-four model with 9 transition rates

     source("HiSSE.null4.9rate.R")
     HiSSE_null4_9rates1<-hisse.null4.mod.9.rates(nwo, host, f=c(0.25,0.32), eps.anc=rep(1,8), trans.type="All.no.dual")
    

##   Reconstruct this
     
##   HiSSE_null4_9rates1_states<-MarginRecon(nwo, host, f=c(0.25,0.32), pars=HiSSE_null4_9rates1$solution, hidden.states=T, aic=HiSSE_null4_9rates1$AIC, verbose=T, four.state.null=T, n.cores=4)

##   Write table

	 write.table(t(c(HiSSE_null4_9rates1$loglik, HiSSE_null4_9rates1$AIC, max(HiSSE_null4_9rates1 $index.par)-1, HiSSE_null4_9rates1$solution)), file="empirical.results.HiSSE.Null4.neb.txt", quote=FALSE, sep="\t", row.names="6", col.names=F, append=TRUE)

